@@ -132,17 +132,36 @@ acled.api <- function(
          acled.api(region = c(1,2), start.date = "2004-08-20", end.date = "2005-05-15") or \n
          acled.api(region = c("Western Africa", "Middle Africa"), start.date = "2004-08-20", end.date = "2005-05-15")', call. = FALSE)
   }
+  region.data.frame <- get.api.regions()[[1]]
   if(is.numeric(region) == TRUE){
+    if(!all(region%in%region.data.frame$code)){
+      invalid.region <- region[!region%in%region.data.frame$code]
+      warning(paste0("Region ",
+                     ifelse(length(invalid.region) > 1, "codes ", "code "),
+                     paste(sub("(.*)", "'\\1'", invalid.region),
+                           collapse = ", "),
+                     " supplied in argument 'region' ",
+                     ifelse(length(invalid.region) > 1, "do", "does"),
+                     " not match the original ACLED region codes.\n",
+                     "Check your spelling, and see the ACLED API User Guide",
+                     " for the correct codes or run get.api.regions()."), call. = FALSE)
+      }
     region1 <- paste0("&region=", paste(region, collapse = "|") )
   }
-  region.data.frame <- get.api.regions()[[1]]
   if(is.character(region) == TRUE){
     char.region <- region.data.frame$code[which(region.data.frame$region%in%region)]
     region1 <- paste0("&region=", paste(char.region, collapse = "|") )
         if(length(region) != length(char.region)){
-          warning('At least one of the region names supplied in argument "region = " does not match the original
-              ACLED region names. Check your spelling, or see the ACLED API Guide for the correct names.', call. = FALSE)
-        }
+          invalid.region <- region[!region %in% region.data.frame$region]
+          warning(paste0("Region ",
+                         ifelse(length(invalid.region) > 1, "names ", "name "),
+                         paste(paste0("'", invalid.region, "'"), collapse = ", "),
+                         " supplied in argument 'region' ",
+                         ifelse(length(invalid.region) > 1, "do", "does"),
+                         " not match the original ACLED region names.\n",
+                         "Check your spelling, and see the ACLED API User Guide",
+                         " for the correct names or run get.api.regions()."), call. = FALSE)
+         }
   }
   if(is.null(region) == TRUE){
     region1 <- ""
@@ -186,12 +205,23 @@ acled.api <- function(
   }
 
   # interaction argument
-  if (!(is.numeric(interaction) | is.null(interaction))) {
+  if(!(is.numeric(interaction) | is.null(interaction))) {
     stop("The 'interaction' argument requires a numeric value.")
-  } else if (!all(interaction %in% c(10:18, 20, 22:28, 30, 33:38, 40, 44:48, 50, 55:58, 60, 66, 68, 78, 80))) {
-    stop(paste0("At least one of the interaction codes supplied to the argument ",
-                "'interaction' does not match the original ACLED interaction codes.\n",
-                "Check the ACLED codebook for the correct codes."))
+  }
+  if(!all(interaction %in% c(10:18, 20, 22:28, 30, 33:38, 40, 44:48, 50,
+                             55:58, 60, 66, 68, 78, 80))){
+    invalid.interaction <- interaction[!interaction %in% c(10:18, 20, 22:28, 30,
+                                                           33:38, 40, 44:48, 50,
+                                                           55:58, 60, 66, 68,
+                                                           78, 80)]
+    warning(paste0("Interaction ",
+                ifelse(length(invalid.interaction) > 1, "codes ", "code "),
+                paste(invalid.interaction, collapse = ', '),
+                " supplied to the argument 'interaction'",
+                ifelse(length(invalid.interaction) > 1, " do", " does"),
+                " not match the",
+                " original ACLED interaction codes.\n",
+                "Check the ACLED codebook for the correct codes."), call. = FALSE)
   }
   interaction1 <- ifelse(is.null(interaction)==TRUE, "",
                          paste0("&", paste0("interaction=", interaction, collapse = ":OR:")))
